@@ -3,7 +3,9 @@ import sys
 from rich.prompt import Prompt, Confirm
 from rich import print
 
-from audit_tools.core import Session, clear, SessionException, export_file
+from audit_tools.core.errors import SessionException
+from audit_tools.core.functions import clear, export_file
+from audit_tools.core.session import Session
 
 
 class Scanner:
@@ -66,11 +68,3 @@ class Scanner:
                 self.count_missed()
             else:
                 break
-
-        try:
-            file_name = export_file(self.session.file_type, None, self.session.variance_items)
-            print(f"> [bold]Exported to [green]{file_name}")
-            sys.exit(1)
-        except SessionException as e:
-            self.session.logger.error(e)
-            print(f"> [bold red]{e}")
